from dataclasses import dataclass, field
from datetime import datetime
from typing import Optional

from mag_tools.model.process_status import ProcessStatus

@dataclass
class PerformanceStatistics:
    time_steps: Optional[int] = field(default=0, metadata={"description": "时间步骤"})
    rollback_steps: Optional[int] = field(default=0, metadata={"description": "回滚步骤"})
    newton_steps: Optional[int] = field(default=0, metadata={"description": "牛顿步骤"})
    liner_cycles: Optional[int] = field(default=0, metadata={"description": "线性循环"})
    amg_cycles: Optional[int] = field(default=0, metadata={"description": "AMG循环"})
    min_dt: Optional[float] = field(default=0, metadata={"description": "最小DT"})
    max_dt: Optional[float] = field(default=0, metadata={"description": "最大DT"})
    total_time: Optional[float] = field(default=0, metadata={"description": "总模拟时间"})
    property_calc: Optional[float] = field(default=0, metadata={"description": "属性计算时间"})
    flow_terms: Optional[float] = field(default=0, metadata={"description": "流量项计算时间"})
    well_thread: Optional[float] = field(default=0, metadata={"description": "井螺纹计算时间"})
    complete_matrix: Optional[float] = field(default=0, metadata={"description": "完整矩阵计算时间"})
    newton_method: Optional[float] = field(default=0, metadata={"description": "牛顿法计算时间"})
    file_writing: Optional[float] = field(default=0, metadata={"description": "文件写入时间"})
    solver_time: Optional[float] = field(default=0, metadata={"description": "求解时间"})
    pressure_factor: Optional[float] = field(default=0, metadata={"description": "压力因子时间"})
    pressure_solve: Optional[float] = field(default=0, metadata={"description": "压力求解时间"})
    pressure_decouple: Optional[float] = field(default=0, metadata={"description": "压力解耦时间"})
    ilu_factor: Optional[float] = field(default=0, metadata={"description": "ILU因子时间"})
    ilu_solve: Optional[float] = field(default=0, metadata={"description": "ILU求解时间"})
    start_time: Optional[datetime] = field(default=None, metadata={"description": "开始模拟的时间"})
    case_file: Optional[str] = field(default=None, metadata={"description": "模型方案文件"})
    parameters: Optional[str] = field(default=None, metadata={"description": "方案参数（json字符串）"})
    status: Optional[ProcessStatus] = field(default=None, metadata={"description": "模拟状态：正在处理、成功或失败"})
    error_message: Optional[str] = field(default=None, metadata={"description": "错误信息"})
    sn: Optional[int] = field(default=None, metadata={"description": "方案模拟序号"})

